@@ -2,6 +2,7 @@
 # Licensed according to the LICENCE file on the main branch
 """Module containing the analysis abstract base class and several basic analyses."""
 from __future__ import annotations
+from dataclasses import dataclass
 
 import inspect
 import json
@@ -14,7 +15,7 @@ from enum import Enum
 from functools import lru_cache, wraps
 from pathlib import Path
 from textwrap import wrap
-from typing import List, Union
+from typing import Dict, List, Union
 
 import lmfit
 import matplotlib
@@ -45,9 +46,17 @@ from quantify_core.visualization.SI_utilities import adjust_axeslabels_SI, set_c
 from .types import AnalysisSettings
 
 
+@dataclass
+class _FiguresMplCache:
+    __slots__ = ["figs", "axes", "initialized"]
+    figs: Dict[str, matplotlib.figure.Figure]
+    axes: Dict[str, matplotlib.axes.Axes]
+    initialized: bool
+
+
 @lru_cache(maxsize=8)
 def _analyses_figures_cache(_: BaseAnalysis):
-    return [None, None]
+    return _FiguresMplCache({}, {}, False)
 
 
 # global configurations at the level of the analysis module
@@ -88,7 +97,7 @@ class AnalysisSteps(Enum):
         from quantify_core.analysis import base_analysis as ba
         print(ba.analysis_steps_to_str(ba.AnalysisSteps))
 
-    .. include:: examples/analysis.base_analysis.AnalysisSteps.py.rst.txt
+    .. include:: examples/analysis.base_analysis.AnalysisSteps.rst.txt
 
     .. tip::
 
@@ -116,14 +125,13 @@ class AnalysisMeta(ABCMeta):
     By convention, analysis object stores figures in ``self.figs_mpl`` and
     ``self.axs_mpl`` dictionaries. This causes troubles for long-running operations,
     because figures are all in memory and eventually this uses all available memory of
-    the PC. In order to avoid it, :meth:`BaseAnalysis.created_figures` and its
-    derivatives are patched so that all the figures are put in LRU cache and lazily
-    constructed upon request to :attr:`BaseAnalysis.figs_mpl` or
-    :attr:`BaseAnalysis.axs_mpl`, and :meth:`BaseAnalysis.created_figures` actually does
-    nothing.
+    the PC. In order to avoid it, :meth:`BaseAnalysis.create_figures` and its
+    derivatives are patched so that all the figures are put in LRU cache and
+    reconstructed upon request to :attr:`BaseAnalysis.figs_mpl` or
+    :attr:`BaseAnalysis.axs_mpl` if they were removed from the cache.
 
     Provided that analyses subclasses follow convention of figures being created in
-    :meth:`BaseAnalysis.created_figures`, this approach should solve the memory issue
+    :meth:`BaseAnalysis.create_figures`, this approach should solve the memory issue
     and preserve reverse compatibility with present code.
     """
 
@@ -133,31 +141,29 @@ class AnalysisMeta(ABCMeta):
             create_figures_orig = namespace.pop("create_figures")
 
             @wraps(create_figures_orig)
-            def dummy_create_figures(_):
-                # We are actually not creating any figures here. Instead, if needed,
-                # they will be created when querying them with Analysis.figs_mpl
-                # or Analysis.axs_mpl
-                pass
+            def create_figures_patched(self):
+                _analyses_figures_cache(self).initialized = True
+                self._creating_figures = True
+                create_figures_orig(self)
+                self._creating_figures = False
 
             def _figs_axs_mpl(self):
                 cache = _analyses_figures_cache(self)
-                if cache[0] is None:
-                    cache[0] = {}
-                    cache[1] = {}
-                    self._create_figures_original()
+                if not cache.initialized and not self._creating_figures:
+                    create_figures_patched(self)
                 return cache
 
             def figs_mpl(self):
-                return self._figs_axs_mpl[0]
+                return self._figs_axs_mpl.figs
 
             def axs_mpl(self):
-                return self._figs_axs_mpl[1]
+                return self._figs_axs_mpl.axes
 
-            namespace["_create_figures_original"] = create_figures_orig
+            namespace["_creating_figures"] = False
             namespace["_figs_axs_mpl"] = property(_figs_axs_mpl)
             namespace["figs_mpl"] = property(figs_mpl)
             namespace["axs_mpl"] = property(axs_mpl)
-            namespace["create_figures"] = dummy_create_figures
+            namespace["create_figures"] = create_figures_patched
 
         return super().__new__(cls, name, bases, namespace, **kwargs)
 
@@ -297,7 +303,7 @@ class BaseAnalysis(metaclass=AnalysisMeta):
 
         This function is typically called right after instantiating an analysis class.
 
-        .. include:: examples/analysis.base_analysis.BaseAnalysis.run_custom_analysis_args.py.rst.txt
+        .. include:: examples/analysis.base_analysis.BaseAnalysis.run_custom_analysis_args.rst.txt
 
         Returns
         -------
