@@ -10,8 +10,9 @@ import os
 import sys
 from collections.abc import Iterable
 from pathlib import Path
-from typing import Union, List, Optional
+from typing import Union, List, Optional, Dict, Any
 from uuid import uuid4
+from copy import deepcopy
 
 import numpy as np
 import xarray as xr
@@ -665,7 +666,6 @@ def concat_dataset(tuids: List[TUID], dim: str = "dim_0") -> xr.Dataset:
 
 def get_varying_parameter_values(
     tuids: List[TUID],
-    instrument: str,
     parameter: str,
 ) -> np.ndarray:
     """
@@ -676,12 +676,10 @@ def get_varying_parameter_values(
     ----------
     tuids:
         The list of TUIDs from which to get the varying parameter.
-    instrument:
-        The name of the instrument from which to get the value. For example
-        "fluxcurrent"
     parameter:
-        The name of the parameter from which to get the value. For example "FBL_0"
-
+        The name and address of the QCoDeS parameter from which to get the
+        value, including the instrument name and all submodules. For example
+        :code:`"current_source.module0.dac0.current"`.
     Returns
     -------
     :
@@ -695,9 +693,7 @@ def get_varying_parameter_values(
         try:
             _tuid = TUID(tuid)
             _snapshot = load_snapshot(_tuid)
-            value.append(
-                _snapshot["instruments"][instrument]["parameters"][parameter]["value"]
-            )
+            value.append(extract_parameter_from_snapshot(_snapshot, parameter)["value"])
         except FileNotFoundError as fnf_error:
             raise FileNotFoundError(fnf_error) from fnf_error
         except ValueError as vl_error:
@@ -711,10 +707,55 @@ def get_varying_parameter_values(
     return values
 
 
+# pylint: disable=redefined-outer-name
+def extract_parameter_from_snapshot(
+    snapshot: Dict[str, Any], parameter: str
+) -> Dict[str, Any]:
+    """
+    A function which takes a parameter and extracts it from a snapshot,
+    including in the case where the parameter is part of a nested submodule
+    within a QCoDeS instrument
+
+    Parameters
+    -----------
+    snapshot:
+        The snapshot
+    parameter:
+        The full address of the QCoDeS parameter as a string, in the format
+        :code:`"instrument.submodule.submodule.parameter"` (an arbitrary
+        number of nested submodules is a allowed).
+
+    Returns
+    -----------
+    parameter_dict
+        The dict specifying the parameter properties which was extracted from the
+        snapshot
+    """
+    parameter_address = parameter.split(".")
+    if len(parameter_address) < 2:
+        raise ValueError(
+            "parameter must be a string of the form 'instrument.submodule.parameter'"
+        )
+
+    sub_snapshot = deepcopy(snapshot)
+
+    try:
+        sub_snapshot = sub_snapshot["instruments"][parameter_address[0]]
+        for submodule in parameter_address[1:-1]:
+            sub_snapshot = sub_snapshot["submodules"][submodule]
+
+        parameter_dict = sub_snapshot["parameters"][parameter_address[-1]]
+    except KeyError as key_error:
+        raise KeyError(
+            f"Parameter {parameter} not found in snapshot. {key_error} not found."
+        ) from key_error
+
+    return parameter_dict
+
+
 # pylint: disable=too-many-arguments
 def multi_experiment_data_extractor(
     experiment: str,
-    instrument: str,
     parameter: str,
     *,
     new_name: Optional[str] = None,
@@ -735,7 +776,9 @@ def multi_experiment_data_extractor(
         The name of the instrument from which to get the value. For example
         "fluxcurrent"
     parameter:
-        The name of the parameter from which to get the value. For example "FBL_0"
+        The name and address of the QCoDeS parameter from which to get the
+        value, including the instrument name and all submodules. For example
+        :code:`"current_source.module0.dac0.current"`.
     new_name:
         The name of the new multifile dataset. If no new name is given, it will
         create a new name as `experiment` vs `instrument`.
@@ -760,7 +803,7 @@ def multi_experiment_data_extractor(
         )
     tuids = get_tuids_containing(experiment, t_start=t_start, t_stop=t_stop)
     if new_name is None:
-        new_name = f"{experiment} vs {instrument}"
+        new_name = f"{experiment} vs {parameter}"
 
     # Necessary to correctly extend the varying_parameter_values
     tuids.sort()
@@ -769,9 +812,7 @@ def multi_experiment_data_extractor(
     new_dataset = concat_dataset(tuids)
 
     # Get the varying parameter from the snapshot.json file
-    varying_parameter_values = get_varying_parameter_values(
-        tuids, instrument, parameter
-    )
+    varying_parameter_values = get_varying_parameter_values(tuids, parameter)
 
     # This counts the number of unique tuids to extend the varying parameter with. This
     # assumes the ref_tuids are sorted.
@@ -781,6 +822,7 @@ def multi_experiment_data_extractor(
         varying_parameter_values, repeats=counts
     )
     _snapshot = load_snapshot(tuids[0])
+    _parameter_dict = extract_parameter_from_snapshot(_snapshot, parameter)
     # Set the varying parameter as a new coordinate
     nr_existing_coords = len(new_dataset.coords)
     coords = {
@@ -789,10 +831,8 @@ def multi_experiment_data_extractor(
             varying_parameter_values_extended,
             dict(
                 is_main_coord=True,
-                long_name=instrument,
-                units=_snapshot["instruments"][instrument]["parameters"][parameter][
-                    "unit"
-                ],
+                long_name=_parameter_dict["label"],
+                units=_parameter_dict["unit"],
                 uniformly_spaced=_is_uniformly_spaced_array(varying_parameter_values),
             ),
         ),
