@@ -1,5 +1,5 @@
 # Repository: https://gitlab.com/quantify-os/quantify-core
-# Licensed according to the LICENCE file on the master branch
+# Licensed according to the LICENCE file on the main branch
 # pylint: disable=invalid-name  # disabled because of capital SI in module name
 """
 Utilities for managing SI units with plotting systems.
@@ -147,8 +147,8 @@ SI_UNITS = (
 
 def SI_prefix_and_scale_factor(val, unit=None):
     """
-    Takes in a value and unit and if applicable returns the proper scale factor
-    and SI prefix.
+    Takes in a value and unit. If the unit is an unscaled SI unit (eg. 'm', but not
+    'mm'), the proper scale factor and SI prefix are returned.
 
     If the unit is None, no scaling is done.
     If the unit is "SI_PREFIX_ONLY", the value is scaled and an SI prefix is applied
@@ -176,9 +176,9 @@ def SI_prefix_and_scale_factor(val, unit=None):
                 if plt.rcParams["text.usetex"] and prefix == "μ":
                     prefix = r"$\mu$"
             if unit == "SI_PREFIX_ONLY":
-                scale_factor, scaled_unit = 10 ** -prefix_power, prefix
+                scale_factor, scaled_unit = 10**-prefix_power, prefix
             else:
-                scale_factor, scaled_unit = 10 ** -prefix_power, prefix + unit
+                scale_factor, scaled_unit = 10**-prefix_power, prefix + unit
         # this exception can be triggered in the pyqtgraph multi processing
         except (KeyError, TypeError):
             scale_factor, scaled_unit = 1, unit
@@ -190,7 +190,7 @@ def SI_prefix_and_scale_factor(val, unit=None):
     return scale_factor, scaled_unit
 
 
-def SI_val_to_msg_str(val: float, unit: str = None, return_type=str):
+def SI_val_to_msg_str(val: Union[float, int], unit: str = None, return_type=str):
     """
     Takes in a value  with optional unit and returns a string tuple consisting of
     (value_str, unit) where the value and unit are rescaled according to SI prefixes,
@@ -205,6 +205,11 @@ def SI_val_to_msg_str(val: float, unit: str = None, return_type=str):
     except TypeError:
         return return_type(val), unit
 
+    # Convert floats to int if possible and if inital value was int
+    if isinstance(val, int):
+        if isinstance(new_val, float) and new_val.is_integer():
+            new_val = int(new_val)
+
     return return_type(new_val), new_unit
 
 
@@ -312,7 +317,7 @@ def format_value_string(
 
     fmt = SafeFormatter(missing="NaN")
     if stderr is not None:
-        val_string = fr": {val_format_specifier}$\pm${err_format_specifier} {{}}{{}}"
+        val_string = rf": {val_format_specifier}$\pm${err_format_specifier} {{}}{{}}"
         # par name is excluded from the format command to allow latex {} characters.
         val_string = par_name + fmt.format(val_string, val, stderr, unit, end_char)
     else:
@@ -322,7 +327,7 @@ def format_value_string(
     return val_string
 
 
-def value_precision(val, stderr=None) -> Tuple[str]:
+def value_precision(val, stderr=None) -> Tuple[str, str]:
     """
     Calculate the precision to which a parameter is to be specified, according to
     its standard error. Returns the appropriate format specifier string.
