@@ -14,7 +14,7 @@ import numpy as np
 import pytest
 import uncertainties
 import xarray as xr
-from qcodes import Instrument, ManualParameter
+from qcodes import Instrument, ManualParameter, InstrumentChannel
 from qcodes.utils.helpers import NumpyJSONEncoder
 
 import quantify_core.data.handling as dh
@@ -706,11 +706,92 @@ def test_concat_dataset(tmp_test_data_dir):
     assert new_dataset["ref_tuids"].is_dataset_ref
 
 
+# pylint: disable=redefined-outer-name
+@pytest.fixture(scope="function", autouse=False)
+def mock_instr_nested(request):
+    """
+    Set up an instrument with a sub module with the following structure
+
+    instr
+    -> a
+    -> mod_a
+        -> b
+    -> mod_b
+        -> mod_c
+            -> c
+    """
+
+    instr = Instrument("DummyInstrument")
+
+    instr.add_parameter("a", parameter_class=ManualParameter, unit="Hz")
+
+    mod_a = InstrumentChannel(instr, "mod_a")
+    mod_a.add_parameter("b", parameter_class=ManualParameter)
+    instr.add_submodule("mod_a", mod_a)
+
+    mod_b = InstrumentChannel(instr, "mod_b")
+    mod_c = InstrumentChannel(instr, "mod_b")
+    mod_b.add_submodule("mod_c", mod_c)
+    mod_c.add_parameter("c", parameter_class=ManualParameter)
+
+    instr.add_submodule("mod_b", mod_b)
+
+    def cleanup_instruments():
+        instr.close()
+
+    request.addfinalizer(cleanup_instruments)
+
+    return instr
+
+
+# pylint: disable=invalid-name
+def test_extract_parameter_from_snapshot(tmp_test_data_dir, mock_instr_nested):
+    """
+    Test that we can extract parameters from a snapshot, including those
+    which are contained within submodules
+    """
+    # Always set datadir before instruments
+    dh.set_datadir(tmp_test_data_dir)
+
+    # set some random values
+    mock_instr_nested.a(23)
+    mock_instr_nested.mod_a.b(42)
+    mock_instr_nested.mod_b.mod_c.c(23.1)
+
+    # create snapshot
+    snap = dh.snapshot()
+
+    a = dh.extract_parameter_from_snapshot(snap, "DummyInstrument.a")["value"]
+    a_unit = dh.extract_parameter_from_snapshot(snap, "DummyInstrument.a")["unit"]
+    b = dh.extract_parameter_from_snapshot(snap, "DummyInstrument.mod_a.b")["value"]
+    c = dh.extract_parameter_from_snapshot(snap, "DummyInstrument.mod_b.mod_c.c")[
+        "value"
+    ]
+
+    assert a == 23
+    assert a_unit == "Hz"
+    assert b == 42
+    assert c == 23.1
+
+
 def test_get_varying_parameter(tmp_test_data_dir):
     dh.set_datadir(tmp_test_data_dir)
-    instrument = "fluxcurrent"
-    parameter = "FBL_4"
-    non_existing_parameter = "FBL_5"
+    parameter = "fluxcurrent.FBL_4"
+    correct_tuids = dh.get_tuids_containing(
+        "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
+    )
+    values = np.array([-0.00100625, -0.000996875, -0.0009875])
+
+    varying_parameter_values = dh.get_varying_parameter_values(correct_tuids, parameter)
+    assert isinstance(varying_parameter_values, np.ndarray)
+    assert len(varying_parameter_values) == len(correct_tuids)
+    assert varying_parameter_values == pytest.approx(values)
+
+
+def test_get_varying_parameter_error(tmp_test_data_dir):
+    dh.set_datadir(tmp_test_data_dir)
+    parameter = "fluxcurrent.FBL_4"
+    non_existing_parameter = "fluxcurrent.FBL_5"
     correct_tuids = dh.get_tuids_containing(
         "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
     )
@@ -721,28 +802,18 @@ def test_get_varying_parameter(tmp_test_data_dir):
     tuid_wrong_values = dh.get_tuids_containing(
         "Pulsed spectroscopy", t_start="2021-10-29", t_stop="2021-10-30"
     ) + ["test"]
-    values = np.array([-0.00100625, -0.000996875, -0.0009875])
 
     with pytest.raises(ValueError):
-        dh.get_varying_parameter_values(tuid_string, instrument, parameter)
+        dh.get_varying_parameter_values(tuid_string, parameter)
 
     with pytest.raises(TypeError):
-        dh.get_varying_parameter_values(tuid_wrong_list, instrument, parameter)
+        dh.get_varying_parameter_values(tuid_wrong_list, parameter)
 
     with pytest.raises(ValueError):
-        dh.get_varying_parameter_values(tuid_wrong_values, instrument, parameter)
+        dh.get_varying_parameter_values(tuid_wrong_values, parameter)
 
     with pytest.raises(KeyError):
-        dh.get_varying_parameter_values(
-            correct_tuids, instrument, non_existing_parameter
-        )
-
-    varying_parameter_values = dh.get_varying_parameter_values(
-        correct_tuids, instrument, parameter
-    )
-    assert isinstance(varying_parameter_values, np.ndarray)
-    assert len(varying_parameter_values) == len(correct_tuids)
-    assert varying_parameter_values == pytest.approx(values)
+        dh.get_varying_parameter_values(correct_tuids, non_existing_parameter)
 
 
 @pytest.mark.parametrize("new_name", [None, "concat"])
@@ -750,8 +821,7 @@ def test_multi_experiment_data_extractor(tmp_test_data_dir, new_name):
     dh.set_datadir(tmp_test_data_dir)
     t_start = "20211029"
     t_stop = "20211030"
-    instrument = "fluxcurrent"
-    parameter = "FBL_4"
+    parameter = "fluxcurrent.FBL_4"
     experiment = "Pulsed spectroscopy"
     experiment_wrong_type = 5
     expected_varying_parameter_values = np.array(
@@ -761,7 +831,6 @@ def test_multi_experiment_data_extractor(tmp_test_data_dir, new_name):
     with pytest.raises(TypeError):
         dh.multi_experiment_data_extractor(
             experiment_wrong_type,
-            instrument,
             parameter,
             new_name=new_name,
             t_start=t_start,
@@ -771,7 +840,6 @@ def test_multi_experiment_data_extractor(tmp_test_data_dir, new_name):
     # Test filling in all parameters and new_name=None
     new_dataset = dh.multi_experiment_data_extractor(
         experiment,
-        instrument,
         parameter,
         new_name=new_name,
         t_start=t_start,
@@ -784,6 +852,6 @@ def test_multi_experiment_data_extractor(tmp_test_data_dir, new_name):
         np.repeat(expected_varying_parameter_values, 240)
     )
     if new_name is None:
-        assert new_dataset.name == f"{experiment} vs {instrument}"
+        assert new_dataset.name == f"{experiment} vs {parameter}"
     else:
         assert new_dataset.name == new_name
